==> eam-wshub-proxyclient-11.4-9-sources.jar: net/datastream/schemas/mp_results/mp7161_001/MP7161_ChangeWorkOrderStatus_001_Result.java <==

package net.datastream.schemas.mp_results.mp7161_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.WOID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *       &lt;attribute name="isCampaignWOActionSuccess" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="true" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP7161_ChangeWorkOrderStatus_001_Result")
public class MP7161_ChangeWorkOrderStatus_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP7161_ChangeWorkOrderStatus_001_Result.ResultData resultData;
    @XmlAttribute(name = "isCampaignWOActionSuccess")
    protected String isCampaignWOActionSuccess;

    /**
     * Obtient la valeur de la propriété resultData.
     * 
     * @return
     *     possible object is
     *     {@link MP7161_ChangeWorkOrderStatus_001_Result.ResultData }
     *     
     */
    public MP7161_ChangeWorkOrderStatus_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Définit la valeur de la propriété resultData.
     * 
     * @param value
     *     allowed object is
     *     {@link MP7161_ChangeWorkOrderStatus_001_Result.ResultData }
     *     
     */
    public void setResultData(MP7161_ChangeWorkOrderStatus_001_Result.ResultData value) {
        this.resultData = value;
    }

    /**
     * Obtient la valeur de la propriété isCampaignWOActionSuccess.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIsCampaignWOActionSuccess() {
        if (isCampaignWOActionSuccess == null) {
            return "true";
        } else {
            return isCampaignWOActionSuccess;
        }
    }

    /**
     * Définit la valeur de la propriété isCampaignWOActionSuccess.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIsCampaignWOActionSuccess(String value) {
        this.isCampaignWOActionSuccess = value;
    }


    /**
     * <p>Classe Java pour anonymous complex type.
     * 
     * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "workorderid"
    })
    public static class ResultData {

        @XmlElement(name = "WORKORDERID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
        protected WOID_Type workorderid;

        /**
         * Obtient la valeur de la propriété workorderid.
         * 
         * @return
         *     possible object is
         *     {@link WOID_Type }
         *     
         */
        public WOID_Type getWORKORDERID() {
            return workorderid;
        }

        /**
         * Définit la valeur de la propriété workorderid.
         * 
         * @param value
         *     allowed object is
         *     {@link WOID_Type }
         *     
         */
        public void setWORKORDERID(WOID_Type value) {
            this.workorderid = value;
        }

    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_results/mp7161_001/MP7161_ChangeWorkOrderStatus_001_Result.java <==

package net.datastream.schemas.mp_results.mp7161_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.WOID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *       &lt;attribute name="isCampaignWOActionSuccess" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="true" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP7161_ChangeWorkOrderStatus_001_Result")
public class MP7161_ChangeWorkOrderStatus_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP7161_ChangeWorkOrderStatus_001_Result.ResultData resultData;
    @XmlAttribute(name = "isCampaignWOActionSuccess")
    protected String isCampaignWOActionSuccess;

    /**
     * Gets the value of the resultData property.
     * 
     * @return
     *     possible object is
     *     {@link MP7161_ChangeWorkOrderStatus_001_Result.ResultData }
     *     
     */
    public MP7161_ChangeWorkOrderStatus_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Sets the value of the resultData property.
     * 
     * @param value
     *     allowed object is
     *     {@link MP7161_ChangeWorkOrderStatus_001_Result.ResultData }
     *     
     */
    public void setResultData(MP7161_ChangeWorkOrderStatus_001_Result.ResultData value) {
        this.resultData = value;
    }

    /**
     * Gets the value of the isCampaignWOActionSuccess property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIsCampaignWOActionSuccess() {
        if (isCampaignWOActionSuccess == null) {
            return "true";
        } else {
            return isCampaignWOActionSuccess;
        }
    }

    /**
     * Sets the value of the isCampaignWOActionSuccess property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIsCampaignWOActionSuccess(String value) {
        this.isCampaignWOActionSuccess = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "workorderid"
    })
    public static class ResultData {

        @XmlElement(name = "WORKORDERID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
        protected WOID_Type workorderid;

        /**
         * Gets the value of the workorderid property.
         * 
         * @return
         *     possible object is
         *     {@link WOID_Type }
         *     
         */
        public WOID_Type getWORKORDERID() {
            return workorderid;
        }

        /**
         * Sets the value of the workorderid property.
         * 
         * @param value
         *     allowed object is
         *     {@link WOID_Type }
         *     
         */
        public void setWORKORDERID(WOID_Type value) {
            this.workorderid = value;
        }

    }

}
